pub struct CssResolver;Implementations
Sourceimpl CssResolver
impl CssResolver
Sourcepub fn resolve(stylesheet: &CssNode) -> ResolvedStyles
pub fn resolve(stylesheet: &CssNode) -> ResolvedStyles
Resolves an author stylesheet into declarations used by layout.
Sourcepub fn resolve_with_origin(
stylesheet: &CssNode,
origin: StyleOrigin,
) -> ResolvedStyles
pub fn resolve_with_origin( stylesheet: &CssNode, origin: StyleOrigin, ) -> ResolvedStyles
Resolves a stylesheet using the supplied cascade origin.
Sourcepub fn resolve_inline_style(style: &str) -> ResolvedStyles
pub fn resolve_inline_style(style: &str) -> ResolvedStyles
Parses declarations from an HTML style attribute.
Inline declarations use author origin but outrank selector-based author
rules of the same importance. Author !important declarations still
outrank normal inline declarations, as required by the cascade.